# eric7.DebugClients.Python.ModuleLoader

Module implementing an import hook patching modules to support debugging.

### Global Attributes

None

### Classes

ModuleLoader | Class implementing an import hook patching modules to support debugging.

### Functions

None

## ModuleLoader

Class implementing an import hook patching modules to support debugging.

### Derived from

None

### Class Attributes

None

### Class Methods

None

### Methods

ModuleLoader | Constructor
__loadModule | Private method to load a module.
create_module | Public method to create a module based on the passed in spec.
exec_module | Public method to execute the created module.
find_spec | Public method returning the module spec.

### Static Methods

None

#### ModuleLoader (Constructor)

ModuleLoader(debugClient)

Constructor

debugClient (DebugClient)
  reference to the debug client object

#### ModuleLoader.__loadModule

__loadModule(fullname)

Private method to load a module.

fullname (str)
  name of the module to be loaded

Return:
  reference to the loaded module

Return Type:
  module

#### ModuleLoader.create_module

create_module(spec)

Public method to create a module based on the passed in spec.

spec (ModuleSpec)
  module spec object for loading the module

Return:
  created and patched module

Return Type:
  module

#### ModuleLoader.exec_module

exec_module(module)

Public method to execute the created module.

module (module)
  module to be executed

#### ModuleLoader.find_spec

find_spec(fullname, path, target=None)

Public method returning the module spec.

fullname (str)
  name of the module to be loaded
path (str)
  path to resolve the module name
target (module)
  module object to use for a more educated guess about what spec to return

Return:
  module spec object pointing to the module loader

Return Type:
  ModuleSpec

Up